"""Experimental syntax notation for decimal literal

n D -> Decimal(n) where n is any number
"""

import token_utils  # Need to be installed separately

__version__ = "0.0.1"

import_statement = "from decimal import Decimal"


def transform_source(source):
    tokens = token_utils.tokenize(source)
    if len(tokens) < 2:
        return source
    for first, second in zip(tokens, tokens[1:]):
        if first.is_number() and second == "D":
            first.string = f"Decimal('{first.string}')"
            second.string = ""

    return token_utils.untokenize(tokens)


if __name__ == "__main__":
    original = "a = 0.33D"
    transformed = "a = Decimal('0.33')"
    assert transform_source(original) == transformed
    print("Looks good")



# pylint: skip-file
from setuptools import setup
from decimal_literal import __version__

with open("README.md", encoding="utf8") as f:
    README = f.read()

setup(
    name="decimal-literal",
    version=__version__,
    description="Experimental syntax for decimal literals",
    long_description=README,
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 1 - Planning",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    url="https://github.com/aroberge/decimal-literal",
    author="André Roberge",
    author_email="Andre.Roberge@gmail.com",
    py_modules=["decimal_literal"],
    python_requires=">=3.6",
)
